/***************************************************************************
 *   Copyright (C) 2007 by Tobias Schwarz   *
 *   mail@tobias-schwarz.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#include "settings.h"
#include <QtGui>

kembossSettings::kembossSettings()
{
   readSettings();
}

void kembossSettings::readSettings()
{
   // Load settings from configuration file / registry
   QSettings settings("kemboss.org", "Configuration");

   ckembossData = settings.value("kemboss_data").toString();
   ckembossDefaultSettings = settings.value("kemboss_default_settings").toString();
   cembossBin = settings.value("emboss_bin").toString();
   cembossHelp = settings.value("emboss_help").toString();
   cembossData = settings.value("emboss_data").toString();
   //cembossAcd = settings.value("emboss_acd").toString();
   ccurrentDir = settings.value("current_dir", QDir::homePath()).toString();
   copenLastSettings = settings.value("open_last_settings", false).toBool();
   cautoCloseProgressWindow = settings.value("auto_close_progress_window", false).toBool();
   cautoShowOutputTab = settings.value("auto_show_output_tab", true).toBool();
   cautoDeleteExistingOutputFile = settings.value("auto_delete_existing_output_file", true).toBool();
   settextEditFont(settings.value("text_edit_font_family", "courier").toString(),settings.value("text_edit_font_size", 10).toInt());
   setwrapLines(settings.value("text_edit_wrap_lines", false).toBool());
}

void kembossSettings::writeSettings() const
{
   QSettings settings("kemboss.org", "Configuration");

   settings.setValue("kemboss_data", ckembossData);
   settings.setValue("kemboss_default_settings", ckembossDefaultSettings);
   settings.setValue("emboss_bin", cembossBin);
   settings.setValue("emboss_help", cembossHelp);
   settings.setValue("emboss_data", cembossData);
   //settings.setValue("emboss_acd", cembossAcd);
   settings.setValue("current_dir", ccurrentDir);
   settings.setValue("open_last_settings", copenLastSettings);
   settings.setValue("auto_close_progress_window", cautoCloseProgressWindow);
   settings.setValue("auto_show_output_tab", cautoShowOutputTab);
   settings.setValue("auto_delete_existing_output_file", cautoDeleteExistingOutputFile);
   settings.setValue("text_edit_font_family", textEditFont().family());
   settings.setValue("text_edit_font_size", textEditFont().pointSize());
   settings.setValue("text_edit_wrap_lines", wrapLines());
}

bool kembossSettings::checkSettings()
{
   // Check if all directories exist. If not check the usual suspects.
   bool allDirsExist = true;
   if (ckembossData.isEmpty() || !QDir(ckembossData).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/kemboss/data").exists()) setkembossData("/usr/share/kemboss/data/");
      else if (QDir("/usr/local/share/kemboss/data").exists()) setkembossData("/usr/local/share/kemboss/data/");
      else
      #endif
      #ifdef Q_WS_WIN
      if (QDir(QCoreApplication::applicationDirPath()+"\\data").exists()) setkembossData(QCoreApplication::applicationDirPath()+"\\data\\");
      else
      #endif
      allDirsExist = false;
   }
   if (ckembossDefaultSettings.isEmpty() || !QDir(ckembossDefaultSettings).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/kemboss/default_settings").exists()) setkembossDefaultSettings("/usr/share/kemboss/default_settings/");
      else if (QDir("/usr/local/share/kemboss/default_settings").exists()) setkembossDefaultSettings("/usr/local/share/kemboss/default_settings/");
      else
      #endif
      #ifdef Q_WS_WIN
      if (QDir(QCoreApplication::applicationDirPath()+"\\default_settings").exists()) setkembossDefaultSettings(QCoreApplication::applicationDirPath()+"\\default_settings\\");
      else
      #endif
      allDirsExist = false;
   }
   if (cembossBin.isEmpty() || !QDir(cembossBin).exists()) {
      #ifdef Q_WS_X11
      if (QFile::exists("/usr/bin/embossversion")) setembossBin("/usr/bin/");
      else if (QFile::exists("/usr/local/bin/embossversion")) setembossBin("/usr/local/bin/");
      else
      #endif
      #ifdef Q_WS_WIN
      QStringList environment = QProcess::systemEnvironment();
      QString path = environment.at(environment.indexOf(QRegExp("^EMBOSS_ROOT=(.*)", Qt::CaseInsensitive)));
      if (QDir(path.mid(12)).exists()) setembossBin(path.mid(12));
      else
      #endif
      allDirsExist = false;
   }
   if (cembossHelp.isEmpty() || !QDir(cembossHelp).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/EMBOSS/doc/html/emboss/apps").exists()) setembossHelp("/usr/share/EMBOSS/doc/html/emboss/apps/");
      else if (QDir("/usr/share/EMBOSS/doc/programs/html").exists()) setembossHelp("/usr/share/EMBOSS/doc/programs/html/");
      else if (QDir("/usr/local/share/EMBOSS/doc/html/emboss/apps").exists()) setembossHelp("/usr/local/share/EMBOSS/doc/html/emboss/apps/");
      else if (QDir("/usr/local/share/EMBOSS/doc/programs/html").exists()) setembossHelp("/usr/local/share/EMBOSS/doc/programs/html/");
      else
      #endif
      #ifdef Q_WS_WIN
      if (QDir(embossBin()+"doc\\programs\\html").exists()) setembossHelp(embossBin()+"doc\\programs\\html\\");
      else
      #endif
      allDirsExist = false;
   }
   if (cembossData.isEmpty() || !QDir(cembossData).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/EMBOSS/data").exists()) setembossData("/usr/share/EMBOSS/data/");
      else if (QDir("/usr/local/share/EMBOSS/data").exists()) setembossData("/usr/local/share/EMBOSS/data/");
      else
      #endif
      #ifdef Q_WS_WIN
      QStringList environment = QProcess::systemEnvironment();
      QString path = environment.at(environment.indexOf(QRegExp("^EMBOSS_DATA=(.*)", Qt::CaseInsensitive)));
      if (QDir(path.mid(12)).exists()) setembossData(path.mid(12));
      else if (QDir(embossBin()+"data").exists()) setembossData(embossBin()+"data\\");
      else
      #endif
      allDirsExist = false;
   }
   /*if (!QDir(cembossAcd).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/EMBOSS/acd").exists()) setembossAcd("/usr/share/EMBOSS/acd/");
      else if (QDir("/usr/local/EMBOSS/acd").exists()) setembossAcd("/usr/local/EMBOSS/acd/");
      else
      #endif
      #ifdef Q_WS_WIN
      QStringList environment = QProcess::systemEnvironment();
      QString path = environment.at(environment.indexOf(QRegExp("^EMBOSS_ACD=(.*)", Qt::CaseInsensitive)));
      if (QDir(path.mid(11)).exists()) setembossAcd(path.mid(12));
      else if (QDir(embossBin()+"acd").exists()) setembossAcd(embossBin()+"acd/");
      else
      #endif
      allDirsExist = false;
   }*/
   return allDirsExist;
}
